@@ -243,7 +243,12 @@ def _blocks(b, even_only=False):
     blocks = []
     rk = b[1]
     # recall: 2-genus_symbol is [scale, rank, det, even/odd, oddity]
-    if rk == 1 and not even_only:
+    if rk == 0:
+        assert b[2] == 1
+        assert b[3] == 0
+        assert b[4] == 0
+        blocks.append(copy(b))
+    elif rk == 1 and not even_only:
         for det in [1, 3, 5, 7]:
             b1 = copy(b)
             b1[2] = det
@@ -304,8 +309,8 @@ def _blocks(b, even_only=False):
                 b1[4] = t
                 blocks.append(b1)
     # convert ints to integers
-    blocks = [[ZZ(i) for i in b] for b in blocks]
-    return blocks
+    return [[ZZ(i) for i in bl] for bl in blocks]
+
 
 def Genus(A, factored_determinant=None):
     r"""
